resource_name :infoscale_configure
include Veritas_Infoscale::Install
require 'chef/log'
Logger = Chef::Log

action :security do
    install_path = "/opt/VRTS/install/installer"
    responsefile_path = node['veritas_infoscale']['responsefile_path']
    default_path = "/opt/VRTS/install/chef"
    responsefile_path,file_exists = get_responsefile_path(responsefile_path, default_path)
    if (file_exists == false)
        raise "The path specified in attribute responsefile_path does not exist"
    end
    ruby_block "pre_security" do
        block do
            installer_ret = verify_install_script(install_path)
            if installer_ret == 1
                raise "Attribute install_script is empty or the installer script " +
                            "[#{install_path}] does not exist"
            end
        end
    end

    #replace all single quotes with double quotes to change in JSON form
    ruby_block "editing response file" do
        block do
            if ::File.exist?("#{responsefile_path}/security.rsp")
                search = "'"
                replace = '"'
                fp = Chef::Util::FileEdit.new("#{responsefile_path}/security.rsp")
                fp.search_file_replace(search, replace)
                fp.write_file
            end
        end
    end

    template "#{responsefile_path}/security.rsp" do
        source 'security.response.erb'
        variables(
            :systems => node['veritas_infoscale']['systems'],
            :secusrgrps => node['veritas_infoscale']['secusrgrps'],
            :defaultaccess => IsAttributeBool(node['veritas_infoscale']['defaultaccess'], 1, "defaultaccess"),
            :eat_security_fips => IsAttributeBool(node['veritas_infoscale']['eat_security_fips'], 1, "eat_security_fips"),
            :reconfigure_security => IsAttributeBool(node['veritas_infoscale']['reconfigure_security'], 1, "reconfigure_security"),
            :keyfile => node['veritas_infoscale']['keyfile'],
            :rsh => IsAttributeBool(node['veritas_infoscale']['rsh'], 1, "rsh"),
            :logpath => node['veritas_infoscale']['logpath'],
            :tmppath => node['veritas_infoscale']['tmppath'],
        )
        mode '0644'
        action :create
    end

    #replace all double quotes with single quotes to avoid string interpolation
    ruby_block "editing response file" do
        block do
            search = '"'
            replace = "'"
            fp = Chef::Util::FileEdit.new("#{responsefile_path}/security.rsp")
            fp.search_file_replace(search, replace)
            fp.write_file
        end
    end

    execute 'veritas_security' do
        command "#{install_path} -responsefile #{responsefile_path}/security.rsp"
    end

    #Move response file path
    ruby_block "post_security" do
        block do
            if responsefile_path.eql?(ENV['HOME'])
                move_responsefile(responsefile_path, "security.rsp")
            end
        end
    end
end

action :fencing do
    install_path = !(::File.exist?('/opt/VRTS/install/installer')) ? node['veritas_infoscale']['install_script'] : '/opt/VRTS/install/installer'
    responsefile_path = node['veritas_infoscale']['responsefile_path']
    default_path = "/opt/VRTS/install/chef"
    responsefile_path,file_exists = get_responsefile_path(responsefile_path, default_path)
    if (file_exists == false)
        raise "The path specified in attribute responsefile_path does not exist"
    end
    ruby_block "pre_fencing" do
        block do
            installer_ret = verify_install_script(install_path)
            if installer_ret == 1
                raise "Attribute install_script is empty or the installer script does not exist"
            end
        end
    end

    #replace all single quotes with double quotes to change in JSON form
    ruby_block "editing response file" do
        block do
            if ::File.exist?("#{responsefile_path}/fencing.rsp")
                search = "'"
                replace = '"'
                fp = Chef::Util::FileEdit.new("#{responsefile_path}/fencing.rsp")
                fp.search_file_replace(search, replace)
                fp.write_file
            end
        end
    end

    template "#{responsefile_path}/fencing.rsp" do
        source 'fencing.response.erb'
        variables(
            :systems => node['veritas_infoscale']['systems'],
            :fencing_option => node['veritas_infoscale']['fencing_option'],
            :fencing_newdg_disks => node['veritas_infoscale']['fencing_newdg_disks'],
            :fencing_dgname => node['veritas_infoscale']['fencing_dgname'],
            :fencing_config_cpagent => IsAttributeBool(node['veritas_infoscale']['fencing_config_cpagent'], 1, "fencing_config_cpagent"),
            :fencing_cpagentgrp => node['veritas_infoscale']['fencing_cpagentgrp'],
            :fencing_cpagent_monitor_freq => node['veritas_infoscale']['fencing_cpagent_monitor_freq'],
            :fencing_auto_refresh_reg => IsAttributeBool(node['veritas_infoscale']['fencing_auto_refresh_reg'], 1, "fencing_auto_refresh_reg"),
            :donotreconfigurefencing => IsAttributeBool(node['veritas_infoscale']['donotreconfigurefencing'], 1, "donotreconfigurefencing"),
            :keyfile => node['veritas_infoscale']['keyfile'],
            :rsh => IsAttributeBool(node['veritas_infoscale']['rsh'], 1, "rsh"),
            :logpath => node['veritas_infoscale']['logpath'],
            :tmppath => node['veritas_infoscale']['tmppath'],
        )
        mode '0644'
        action :create
    end

    #replace all double quotes with single quotes to avoid string interpolation
    ruby_block "editing response file" do
        block do
            search = '"'
            replace = "'"
            fp = Chef::Util::FileEdit.new("#{responsefile_path}/fencing.rsp")
            fp.search_file_replace(search, replace)
            fp.write_file
        end
    end

    execute 'veritas_fencing' do
        command "#{install_path} -responsefile #{responsefile_path}/fencing.rsp"
    end

    #Move response file path
    ruby_block "post_fencing" do
        block do
            if responsefile_path.eql?(ENV['HOME'])
                move_responsefile(responsefile_path, "fencing.rsp")
            end
        end
    end
end
